@@ -24,7 +24,11 @@ from .exceptions import (
     ValidationError,
 )
 from .metric_data_expression_parser import parse_expression
-from .utils import make_arn_for_alarm, make_arn_for_dashboard
+from .utils import (
+    make_arn_for_alarm,
+    make_arn_for_dashboard,
+    make_arn_for_rule,
+)
 
 _EMPTY_LIST: Any = tuple()
 
@@ -304,9 +308,9 @@ class MetricAggregatedDatum(MetricDatumBase):
 
 
 class Dashboard(BaseModel):
-    def __init__(self, account_id: str, name: str, body: str):
+    def __init__(self, account_id: str, region_name: str, name: str, body: str):
         # Guaranteed to be unique for now as the name is also the key of a dictionary where they are stored
-        self.arn = make_arn_for_dashboard(account_id, name)
+        self.arn = make_arn_for_dashboard(account_id, region_name, name)
         self.name = name
         self.body = body
         self.last_modified = datetime.now()
@@ -433,6 +437,25 @@ class Statistics:
         )
 
 
+class InsightRule(BaseModel):
+    def __init__(
+        self,
+        account_id: str,
+        region_name: str,
+        definition: str,
+        name: str,
+        state: str,
+        schema: Optional[str],
+        managed_rule: Optional[bool],
+    ):
+        self.definition = definition
+        self.name = name
+        self.schema = schema or '{"Name" : "CloudWatchLogRule", "Version" : 1}'
+        self.state = state
+        self.managed_rule = managed_rule or False
+        self.rule_arn = make_arn_for_rule(region_name, account_id, name)
+
+
 class CloudWatchBackend(BaseBackend):
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
@@ -440,6 +463,7 @@ class CloudWatchBackend(BaseBackend):
         self.dashboards: Dict[str, Dashboard] = {}
         self.metric_data: List[MetricDatumBase] = []
         self.paged_metric_data: Dict[str, List[MetricDatumBase]] = {}
+        self.insight_rules: Dict[str, InsightRule] = {}
         self.tagger = TaggingService()
 
     @property
@@ -449,7 +473,11 @@ class CloudWatchBackend(BaseBackend):
         providers = CloudWatchMetricProvider.__subclasses__()
         md = []
         for provider in providers:
-            md.extend(provider.get_cloudwatch_metrics(self.account_id))
+            md.extend(
+                provider.get_cloudwatch_metrics(
+                    self.account_id, region=self.region_name
+                )
+            )
         return md
 
     def put_metric_alarm(
@@ -572,7 +600,7 @@ class CloudWatchBackend(BaseBackend):
         for metric_member in metric_data:
             # Preserve "datetime" for get_metric_statistics comparisons
             timestamp = metric_member.get("Timestamp")
-            if timestamp is not None and type(timestamp) != datetime:
+            if timestamp is not None and type(timestamp) is not datetime:
                 timestamp = parser.parse(timestamp)
             metric_name = metric_member["MetricName"]
             dimension = metric_member.get("Dimensions.member", _EMPTY_LIST)
@@ -586,7 +614,7 @@ class CloudWatchBackend(BaseBackend):
                 for i in range(0, len(values)):
                     value = values[i]
                     timestamp = metric_member.get("Timestamp")
-                    if timestamp is not None and type(timestamp) != datetime:
+                    if timestamp is not None and type(timestamp) is not datetime:
                         timestamp = parser.parse(timestamp)
 
                     # add the value count[i] times
@@ -655,7 +683,16 @@ class CloudWatchBackend(BaseBackend):
         results = []
         results_to_return = []
         metric_stat_queries = [q for q in queries if "MetricStat" in q]
-        expression_queries = [q for q in queries if "Expression" in q]
+        metric_math_expression_queries = [
+            q
+            for q in queries
+            if "Expression" in q and not q["Expression"].startswith("SELECT")
+        ]
+        metric_insights_expression_queries = [
+            q
+            for q in queries
+            if "Expression" in q and q["Expression"].startswith("SELECT")
+        ]
         for query in metric_stat_queries:
             period_start_time = start_time
             metric_stat = query["MetricStat"]
@@ -726,8 +763,9 @@ class CloudWatchBackend(BaseBackend):
                         "timestamps": timestamps,
                     }
                 )
-        for query in expression_queries:
-            label = query.get("Label") or f"{query_name} {stat}"
+        # Metric Math expression Queries run on top of the results of other queries
+        for query in metric_math_expression_queries:
+            label = query.get("Label") or query["Id"]
             result_vals, timestamps = parse_expression(query["Expression"], results)
             results_to_return.append(
                 {
@@ -737,6 +775,44 @@ class CloudWatchBackend(BaseBackend):
                     "timestamps": timestamps,
                 }
             )
+        # Metric Insights Expression Queries act on all results, and are essentially SQL queries
+        for query in metric_insights_expression_queries:
+            period_start_time = start_time
+            delta = timedelta(seconds=int(query["Period"]))
+            result_vals: List[SupportsFloat] = []  # type: ignore[no-redef]
+            timestamps: List[str] = []  # type: ignore[no-redef]
+            while period_start_time <= end_time:
+                period_end_time = period_start_time + delta
+                period_md = [
+                    period_md
+                    for period_md in period_data
+                    if period_start_time <= period_md.timestamp < period_end_time
+                ]
+
+                # https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch-metrics-insights-querylanguage.html
+                # We should filter even further, but Moto currently does not support Metrics Insights Queries
+                # Let's just add all metric data found within this period
+
+                if len(period_md) > 0:
+                    stats = Statistics(["Sum"], period_start_time)
+                    stats.metric_data = period_md
+                    result_vals.append(stats.get_statistics_for_type("Sum"))  # type: ignore[arg-type]
+
+                    timestamps.append(stats.timestamp)
+                period_start_time += delta
+            if scan_by == "TimestampDescending" and len(timestamps) > 0:
+                timestamps.reverse()
+                result_vals.reverse()
+
+            results_to_return.append(
+                {
+                    "id": query["Id"],
+                    "label": (query.get("Label") or query["Id"]),
+                    "vals": result_vals,
+                    "timestamps": timestamps,
+                }
+            )
+
         return results_to_return
 
     def get_metric_statistics(
@@ -805,7 +881,7 @@ class CloudWatchBackend(BaseBackend):
         return self.metric_data + self.aws_metric_data
 
     def put_dashboard(self, name: str, body: str) -> None:
-        self.dashboards[name] = Dashboard(self.account_id, name, body)
+        self.dashboards[name] = Dashboard(self.account_id, self.region_name, name, body)
 
     def list_dashboards(self, prefix: str = "") -> Iterable[Dashboard]:
         for key, value in self.dashboards.items():
@@ -960,5 +1036,97 @@ class CloudWatchBackend(BaseBackend):
                         f'Missing required parameter in MetricData[{query_num}].StatisticValues: "{stat}"'
                     )
 
+    def put_insight_rule(
+        self,
+        name: str,
+        state: str,
+        definition: str,
+        tags: Optional[List[Dict[str, str]]] = None,
+    ) -> InsightRule:
+        rule = InsightRule(
+            account_id=self.account_id,
+            region_name=self.region_name,
+            definition=definition,
+            name=name,
+            state=state,
+            schema='{"Name" : "CloudWatchLogRule", "Version" : 1}',
+            managed_rule=False,
+        )
+        if tags:
+            self.tagger.tag_resource(rule.rule_arn, tags)
+
+        self.insight_rules[name] = rule
+
+        return rule
+
+    def describe_insight_rules(
+        self,
+        next_token: Optional[str] = "",
+        max_results: Optional[int] = 500,
+    ) -> List[InsightRule]:
+        rules = list(self.insight_rules.values())
+
+        if max_results is None or len(rules) <= max_results:
+            return rules
+
+        return rules[:max_results]
+
+    def delete_insight_rules(self, rule_names: List[str]) -> List[Dict[str, Any]]:
+        failures = []
+        for rule_name in list(self.insight_rules.keys()):
+            if rule_name in rule_names:
+                rule = self.insight_rules.get(rule_name)
+                if rule and rule.managed_rule:
+                    failures.append(
+                        {
+                            "FailureResource": rule_name,
+                            "ExceptionType": "InvalidParameterValue",
+                            "FailureCode": 400,
+                            "FailureDescription": "The value of an input parameter is bad or out-of-range.",
+                        }
+                    )
+                else:
+                    del self.insight_rules[rule_name]
+
+        return failures
+
+    def disable_insight_rules(self, rule_names: List[str]) -> List[Dict[str, Any]]:
+        failures = []
+        for rule_name in list(self.insight_rules.keys()):
+            if rule_name in rule_names:
+                rule = self.insight_rules.get(rule_name)
+                if rule and rule.managed_rule:
+                    failures.append(
+                        {
+                            "FailureResource": rule_name,
+                            "ExceptionType": "InvalidParameterValue",
+                            "FailureCode": 400,
+                            "FailureDescription": "The value of an input parameter is bad or out-of-range.",
+                        }
+                    )
+                else:
+                    self.insight_rules[rule_name].state = "DISABLED"
+
+        return failures
+
+    def enable_insight_rules(self, rule_names: List[str]) -> List[Dict[str, Any]]:
+        failures = []
+        for rule_name in list(self.insight_rules.keys()):
+            if rule_name in rule_names:
+                rule = self.insight_rules.get(rule_name)
+                if rule and rule.managed_rule:
+                    failures.append(
+                        {
+                            "FailureResource": rule_name,
+                            "ExceptionType": "InvalidParameterValue",
+                            "FailureCode": 400,
+                            "FailureDescription": "The value of an input parameter is bad or out-of-range.",
+                        }
+                    )
+                else:
+                    self.insight_rules[rule_name].state = "ENABLED"
+
+        return failures
+
 
 cloudwatch_backends = BackendDict(CloudWatchBackend, "cloudwatch")
