@@ -1,11 +1,14 @@
 import datetime
 import inspect
 import re
-from gzip import decompress
+from functools import cache
+from gzip import compress, decompress
 from typing import Any, Callable, Dict, List, Optional, Tuple
 from urllib.parse import ParseResult, urlparse
 
 from botocore.exceptions import ClientError
+from botocore.loaders import create_loader
+from botocore.model import ServiceModel
 
 from ..settings import get_s3_custom_endpoints
 from .common_types import TYPE_RESPONSE
@@ -328,23 +331,31 @@ def merge_dicts(
     :param dict dict1: the dictionary to be updated.
     :param dict dict2: a dictionary of keys/values to be merged into dict1.
 
-    :param bool remove_nulls: If true, updated values equal to None or an empty dictionary
+    :param bool remove_nulls: If true, updated values equal to None
         will be removed from dict1.
     """
     for key in dict2:
         if isinstance(dict2[key], dict):
-            if key in dict1 and key in dict2:
+            if key in dict1 and isinstance(dict1[key], dict):
                 merge_dicts(dict1[key], dict2[key], remove_nulls)
             else:
                 dict1[key] = dict2[key]
-            if dict1[key] == {} and remove_nulls:
-                dict1.pop(key)
+                if isinstance(dict1[key], dict):
+                    remove_null_from_dict(dict1)
         else:
             dict1[key] = dict2[key]
             if dict1[key] is None and remove_nulls:
                 dict1.pop(key)
 
 
+def remove_null_from_dict(dct: Dict[str, Any]) -> None:
+    for key in list(dct.keys()):
+        if dct[key] is None:
+            dct.pop(key)
+        elif isinstance(dct[key], dict):
+            remove_null_from_dict(dct[key])
+
+
 def aws_api_matches(pattern: str, string: Any) -> bool:
     """
     AWS API can match a value based on a glob, or an exact match
@@ -393,12 +404,17 @@ def gzip_decompress(body: bytes) -> bytes:
     return decompress(body)
 
 
-def get_partition_from_region(region_name: str) -> str:
-    # Very rough implementation
-    # In an ideal world we check `boto3.Session.get_partition_for_region`, but that is quite computationally heavy
-    if region_name.startswith("cn-"):
-        return "aws-cn"
-    return "aws"
+def gzip_compress(body: bytes) -> bytes:
+    return compress(body)
+
+
+ISO_REGION_DOMAINS = {
+    "iso": "c2s.ic.gov",
+    "isob": "sc2s.sgov.gov",
+    "isoe": "cloud.adc-e.uk",
+    "isof": "csp.hci.ic.gov",
+}
+ALT_DOMAIN_SUFFIXES = list(ISO_REGION_DOMAINS.values()) + ["amazonaws.com.cn"]
 
 
 def get_equivalent_url_in_aws_domain(url: str) -> Tuple[ParseResult, bool]:
@@ -414,14 +430,7 @@ def get_equivalent_url_in_aws_domain(url: str) -> Tuple[ParseResult, bool]:
 
     # https://github.com/getmoto/moto/pull/6412
     # Support ISO regions
-    iso_region_domains = [
-        "amazonaws.com.cn",
-        "c2s.ic.gov",
-        "sc2s.sgov.gov",
-        "cloud.adc-e.uk",
-        "csp.hci.ic.gov",
-    ]
-    for domain in iso_region_domains:
+    for domain in ALT_DOMAIN_SUFFIXES:
         if host.endswith(domain):
             host = host.replace(domain, "amazonaws.com")
 
@@ -443,3 +452,11 @@ def get_equivalent_url_in_aws_domain(url: str) -> Tuple[ParseResult, bool]:
             fragment=parsed.fragment,
         )
         return (result, True)
+
+
+@cache
+def get_service_model(service_name: str) -> ServiceModel:
+    loader = create_loader()
+    model = loader.load_service_model(service_name, "service-2")
+    service_model = ServiceModel(model, service_name)
+    return service_model
