@@ -1,4 +1,5 @@
 import json
+from datetime import datetime
 from typing import Any, Dict, List
 
 from moto.core.common_types import TYPE_RESPONSE
@@ -14,6 +15,13 @@ from .models import (
 )
 
 
+class DateTimeEncoder(json.JSONEncoder):
+    def default(self, o: Any) -> Any:
+        if isinstance(o, datetime):
+            return o.isoformat()
+        return super().default(o)
+
+
 class GlueResponse(BaseResponse):
     def __init__(self) -> None:
         super().__init__(service_name="glue")
@@ -396,6 +404,22 @@ class GlueResponse(BaseResponse):
         job_run = self.glue_backend.get_job_run(name, run_id)  # type: ignore[arg-type]
         return json.dumps({"JobRun": job_run.as_dict()})
 
+    def get_job_runs(self) -> str:
+        job_name = self._get_param("JobName")
+        next_token = self._get_param("NextToken")
+        max_results = self._get_int_param("MaxResults")
+        job_runs, next_token = self.glue_backend.get_job_runs(
+            job_name,
+            next_token=next_token,
+            max_results=max_results,
+        )
+        return json.dumps(
+            dict(
+                JobRuns=[job_run.as_dict() for job_run in job_runs],
+                NextToken=next_token,
+            )
+        )
+
     def list_jobs(self) -> str:
         next_token = self._get_param("NextToken")
         max_results = self._get_int_param("MaxResults")
@@ -793,3 +817,96 @@ class GlueResponse(BaseResponse):
         endpoint_name = self._get_param("EndpointName")
         dev_endpoint = self.glue_backend.get_dev_endpoint(endpoint_name)
         return json.dumps({"DevEndpoint": dev_endpoint.as_dict()})
+
+    def create_connection(self) -> str:
+        catalog_id = self._get_param("CatalogId")
+        connection_input = self._get_param("ConnectionInput")
+        tags = self._get_param("Tags")
+        create_connection_status = self.glue_backend.create_connection(
+            catalog_id=catalog_id,
+            connection_input=connection_input,
+            tags=tags,
+        )
+        return json.dumps(dict(CreateConnectionStatus=create_connection_status))
+
+    def get_connection(self) -> str:
+        catalog_id = self._get_param("CatalogId")
+        name = self._get_param("Name")
+        hide_password = self._get_param("HidePassword")
+        apply_override_for_compute_environment = self._get_param(
+            "ApplyOverrideForComputeEnvironment"
+        )
+        connection = self.glue_backend.get_connection(
+            catalog_id=catalog_id,
+            name=name,
+            hide_password=hide_password,
+            apply_override_for_compute_environment=apply_override_for_compute_environment,
+        )
+        return json.dumps(dict(Connection=connection.as_dict()))
+
+    def get_connections(self) -> str:
+        catalog_id = self._get_param("CatalogId")
+        filter = self._get_param("Filter")
+        hide_password = self._get_param("HidePassword")
+        next_token = self._get_param("NextToken")
+        max_results = self._get_param("MaxResults")
+        connections, next_token = self.glue_backend.get_connections(
+            catalog_id=catalog_id,
+            filter=filter,
+            hide_password=hide_password,
+            next_token=next_token,
+            max_results=max_results,
+        )
+        connection_list = [connection.as_dict() for connection in connections]
+        return json.dumps(dict(ConnectionList=connection_list, NextToken=next_token))
+
+    def put_data_catalog_encryption_settings(self) -> str:
+        params = self.parameters
+        catalog_id = params.get("CatalogId", None)
+        data_catalog_encryption_settings = params.get(
+            "DataCatalogEncryptionSettings", {}
+        )
+
+        self.glue_backend.put_data_catalog_encryption_settings(
+            catalog_id=catalog_id,
+            data_catalog_encryption_settings=data_catalog_encryption_settings,
+        )
+
+        return json.dumps({})
+
+    def get_data_catalog_encryption_settings(self) -> str:
+        params = self.parameters
+        catalog_id = params.get("CatalogId", None)
+
+        response = self.glue_backend.get_data_catalog_encryption_settings(
+            catalog_id=catalog_id,
+        )
+
+        return json.dumps(response)
+
+    def put_resource_policy(self) -> str:
+        params = json.loads(self.body)
+        policy_in_json = params.get("PolicyInJson")
+        resource_arn = params.get("ResourceArn")
+        policy_hash_condition = params.get("PolicyHashCondition")
+        policy_exists_condition = params.get("PolicyExistsCondition")
+        enable_hybrid = params.get("EnableHybrid")
+
+        policy_hash = self.glue_backend.put_resource_policy(
+            policy_in_json=policy_in_json,
+            resource_arn=resource_arn,
+            policy_hash_condition=policy_hash_condition,
+            policy_exists_condition=policy_exists_condition,
+            enable_hybrid=enable_hybrid,
+        )
+
+        return json.dumps(policy_hash, cls=DateTimeEncoder)
+
+    def get_resource_policy(self) -> str:
+        params = json.loads(self.body)
+        resource_arn = params.get("ResourceArn")
+        response = self.glue_backend.get_resource_policy(
+            resource_arn=resource_arn,
+        )
+
+        return json.dumps(response, cls=DateTimeEncoder)
