@@ -216,9 +216,9 @@ class EmailResponse(BaseResponse):
 
     def describe_configuration_set(self) -> str:
         configuration_set_name = self.querystring.get("ConfigurationSetName")[0]  # type: ignore
-        self.backend.describe_configuration_set(configuration_set_name)
+        config_set = self.backend.describe_configuration_set(configuration_set_name)
         template = self.response_template(DESCRIBE_CONFIGURATION_SET)
-        return template.render(name=configuration_set_name)
+        return template.render(name=config_set.configuration_set_name)
 
     def create_configuration_set_event_destination(self) -> str:
         configuration_set_name = self._get_param("ConfigurationSetName")
@@ -378,6 +378,48 @@ class EmailResponse(BaseResponse):
         template = self.response_template(GET_IDENTITY_VERIFICATION_ATTRIBUTES_TEMPLATE)
         return template.render(verification_attributes=verification_attributes)
 
+    def delete_configuration_set(self) -> str:
+        params = self._get_params()
+        configuration_set_name = params.get("ConfigurationSetName")
+        if configuration_set_name:
+            self.backend.delete_configuration_set(
+                configuration_set_name=str(configuration_set_name),
+            )
+            template = self.response_template(DELETE_CONFIGURATION_SET_TEMPLATE)
+        return template.render()
+
+    def list_configuration_sets(self) -> str:
+        params = self._get_params()
+        next_token = params.get("NextToken")
+        max_items = params.get("MaxItems")
+        configuration_sets, next_token = self.backend.list_configuration_sets(
+            next_token=next_token,
+            max_items=max_items,
+        )
+        config_set_names = [c.configuration_set_name for c in configuration_sets]
+        template = self.response_template(LIST_CONFIGURATION_SETS_TEMPLATE)
+        return template.render(
+            configuration_sets=config_set_names, next_token=next_token
+        )
+
+    def update_configuration_set_reputation_metrics_enabled(self) -> str:
+        configuration_set_name = self._get_param("ConfigurationSetName")
+        enabled = self._get_param("Enabled")
+        self.backend.update_configuration_set_reputation_metrics_enabled(
+            configuration_set_name=configuration_set_name,
+            enabled=enabled,
+        )
+        template = self.response_template(
+            UPDATE_CONFIGURATION_SET_REPUTATION_METRICS_ENABLED_RESPONSE
+        )
+        return template.render()
+
+    def get_identity_dkim_attributes(self) -> str:
+        identities = self._get_multi_param("Identities.member.")
+        dkim_attributes = self.backend.get_identity_dkim_attributes(identities)
+        template = self.response_template(GET_IDENTITY_DKIM_ATTRIBUTES_RESPONSE)
+        return template.render(dkim_attributes=dkim_attributes)
+
 
 VERIFY_EMAIL_IDENTITY = """<VerifyEmailIdentityResponse xmlns="http://ses.amazonaws.com/doc/2010-12-01/">
   <VerifyEmailIdentityResult/>
@@ -814,3 +856,59 @@ GET_IDENTITY_VERIFICATION_ATTRIBUTES_TEMPLATE = """<GetIdentityVerificationAttri
     <RequestId>d435c1b8-a225-4b89-acff-81fcf7ef9236</RequestId>
   </ResponseMetadata>
 </GetIdentityVerificationAttributesResponse>"""
+
+DELETE_CONFIGURATION_SET_TEMPLATE = """<DeleteConfigurationSetResponse xmlns="http://ses.amazonaws.com/doc/2010-12-01/">
+  <ResponseMetadata>
+    <RequestId>1549581b-12b7-11e3-895e-1334aEXAMPLE</RequestId>
+  </ResponseMetadata>
+  <DeleteConfigurationSetResult/>
+</DeleteConfigurationSetResponse>"""
+
+LIST_CONFIGURATION_SETS_TEMPLATE = """<ListConfigurationSetsResponse xmlns="http://ses.amazonaws.com/doc/2010-12-01/">
+  <ResponseMetadata>
+    <RequestId>1549581b-12b7-11e3-895e-1334aEXAMPLE</RequestId>
+  </ResponseMetadata>
+  <ListConfigurationSetsResult>
+    <ConfigurationSets>
+{% for configurationset in configuration_sets %}
+      <member>
+        <Name>{{ configurationset }}</Name>
+      </member>
+{% endfor %}
+    </ConfigurationSets>
+    <NextToken>{{ next_token }}</NextToken>
+  </ListConfigurationSetsResult>
+</ListConfigurationSetsResponse>"""
+
+UPDATE_CONFIGURATION_SET_REPUTATION_METRICS_ENABLED_RESPONSE = """<UpdateConfigurationSetReputationMetricsEnabledResponse xmlns="http://ses.amazonaws.com/doc/2010-12-01/">
+  <UpdateConfigurationSetReputationMetricsEnabledResult/>
+  <ResponseMetadata>
+    <RequestId>47e0ef1a-9bf2-11e1-9279-0100e8cf109a</RequestId>
+  </ResponseMetadata>
+</UpdateConfigurationSetReputationMetricsEnabledResponse>"""
+
+GET_IDENTITY_DKIM_ATTRIBUTES_RESPONSE = """<GetIdentityDkimAttributesResponse xmlns="http://ses.amazonaws.com/doc/2010-12-01/">
+  <GetIdentityDkimAttributesResult>
+    <DkimAttributes>
+      {% for identity, attributes in dkim_attributes.items() %}
+      <entry>
+        <key>{{ identity }}</key>
+        <value>
+          <DkimEnabled>{{ attributes.DkimEnabled|lower }}</DkimEnabled>
+          <DkimVerificationStatus>{{ attributes.DkimVerificationStatus }}</DkimVerificationStatus>
+          {% if attributes.get('DkimTokens') %}
+          <DkimTokens>
+            {% for token in attributes.DkimTokens %}
+            <member>{{ token }}</member>
+            {% endfor %}
+          </DkimTokens>
+          {% endif %}
+        </value>
+      </entry>
+      {% endfor %}
+    </DkimAttributes>
+  </GetIdentityDkimAttributesResult>
+  <ResponseMetadata>
+    <RequestId>9662c15b-c469-11e1-99d1-797d6ecd6414</RequestId>
+  </ResponseMetadata>
+</GetIdentityDkimAttributesResponse>"""
